@@ -1,3 +1,18 @@
+"""
+Copyright 2012 Dian-Je Tsai and Wantoto Inc
+
+Licensed under the Apache License, Version 2.0 (the "License");
+you may not use this file except in compliance with the License.
+You may obtain a copy of the License at
+
+    http://www.apache.org/licenses/LICENSE-2.0
+
+Unless required by applicable law or agreed to in writing, software
+distributed under the License is distributed on an "AS IS" BASIS,
+WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+See the License for the specific language governing permissions and
+limitations under the License.
+"""
 import datetime
 import os
 import re
@@ -24,6 +39,7 @@ env.roledefs.update({
 
 def deploy_setting(project_name=None, deploy_settings_path=None, **setting_patches):
     """Get deploy_settings.
+
     This method will be called by deploy task.
     If you defined one of project_name and deploy_settings in fabric's env, you don't have to call this.
     If you don't define it, call this before execute deploy task.
@@ -99,6 +115,7 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
         If this is first-time deploy, the value will be forced to True.
     """
     # Get deploy settings and project name
+    global gitignores, pyc_pattern, raw_gitignores, project_src_root_gitignore
     execute(deploy_setting, project_name=project_name,
         deploy_settings_path=deploy_settings_path, **additional_settings)
     project_name = env.project_name
@@ -288,8 +305,7 @@ def deploy(project_name=None, deploy_settings_path=None, commit_msg='deploy',
 
 @roles('web_servers')
 def deploy_to_remote():
-    """
-    This is the private core task who really do deploy to web servers.
+    """This is the private core task who really do deploy to web servers.
     Call "deploy" task. Don't call this directly.
     """
     # local inner function
@@ -447,7 +463,8 @@ def deploy_to_remote():
 
     # Setup Remote
     if deploy_settings.get('RUN_REMOTE_SETUP'):
-        remote_setup_path = deploy_settings.get('REMOTE_SETUP_SCRIPT', os.path.join(remote_project_source_root, project_name, 'remote_setup.py'))
+        remote_setup_path = deploy_settings.get('REMOTE_SETUP_SCRIPT',
+            os.path.join(remote_project_source_root, project_name, 'remote_setup.py'))
         print(cyan('Setup remote'))
         if target_file_existence(remote_setup_path):
             target_run('chmod u+x %s'%remote_setup_path)
@@ -464,7 +481,7 @@ def deploy_to_remote():
 
     # Install venv
     if deploy_settings.get('CHECK_PIP_REQUIREMENTS'):
-        print_title('Install/Upgrade virtualenv for your project')
+        print_title('Install/Upgrade python packages for your project (virtualenv)')
         with fab_settings(virtual_env(remote_project_venv), target_cd(remote_project_path)):
             target_run('pip install -r %s/requirements.txt'%source_root_name)
 
